@@ -415,8 +415,7 @@ L<Mojo::Content> can emit the following events.
     ...
   });
 
-Emitted once all data has been written. Note that this event is EXPERIMENTAL
-and might change without warning!
+Emitted once all data has been written.
 
   $content->on(drain => sub {
     my $content = shift;
