@@ -8,7 +8,7 @@ use overload
 use Carp 'croak';
 use Mojo::Util 'unquote';
 
-has [qw/name path value version/];
+has [qw/name value/];
 
 my $COOKIE_SEPARATOR_RE = qr/^\s*\,\s*/;
 my $NAME_RE             = qr/
@@ -34,6 +34,9 @@ my $VALUE_RE     = qr/
 #  but he is not a porn star."
 sub to_string { croak 'Method "to_string" not implemented by subclass' }
 
+# DEPRECATED in Leaf Fluttering In Wind!
+sub version { warn "Mojo::Cookie->version is DEPRECATED!\n" }
+
 sub _tokenize {
   my ($self, $string) = @_;
 
@@ -100,13 +103,6 @@ L<Mojo::Cookie> implements the following attributes.
 
 Cookie name.
 
-=head2 C<path>
-
-  my $path = $cookie->path;
-  $cookie  = $cookie->path('/test');
-
-Cookie path.
-
 =head2 C<value>
 
   my $value = $cookie->value;
@@ -114,13 +110,6 @@ Cookie path.
 
 Cookie value.
 
-=head2 C<version>
-
-  my $version = $cookie->version;
-  $cookie     = $cookie->version(1);
-
-Cookie version.
-
 =head1 METHODS
 
 L<Mojo::Cookie> inherits all methods from L<Mojo::Base> and implements the
