@@ -166,15 +166,14 @@ sub singleton { state $loop ||= shift->SUPER::new }
 sub start {
   my $self = shift;
   $self = $self->singleton unless ref $self;
-  croak 'Mojo::IOLoop already running' if $self->{running}++;
+  croak 'Mojo::IOLoop already running' if $self->is_running;
   $self->iowatcher->start;
   return $self;
 }
 
 sub stop {
   my $self = shift;
-  $self = $self->singleton unless ref $self;
-  $self->iowatcher->stop if delete $self->{running};
+  (ref $self ? $self : $self->singleton)->iowatcher->stop;
 }
 
 sub stream {
