@@ -26,6 +26,9 @@ sub register {
     );
   }
 
+  # Add "config" helper
+  $app->helper(config => sub { shift->app->config(@_) });
+
   # Add "content" helper
   $app->helper(content => sub { shift->render_content(@_) });
 
@@ -139,6 +142,12 @@ L<Mojolicious::Plugin::DefaultHelpers> implements the following helpers.
 
 Alias for L<Mojolicious::Controller/"app">.
 
+=head2 C<config>
+
+  %= config 'something'
+
+Alias for L<Mojo/"config">.
+
 =head2 C<content>
 
   %= content
